"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const probot_1 = require("probot");
const resolver_1 = require("probot/lib/resolver");
const private_key_1 = require("probot/lib/private-key");
const probot_2 = require("./views/probot");
const micro_1 = require("micro");
let probot;
const loadProbot = (appFn) => {
    const privateKey = private_key_1.findPrivateKey();
    if (!privateKey) {
        throw new Error('Private key not found');
    }
    if (process.env.APP_ID === undefined) {
        throw new Error('APP_ID not set');
    }
    if (process.env.WEBHOOK_SECRET === undefined) {
        throw new Error('WEBHOOK_SECRET not set');
    }
    probot =
        probot ||
            probot_1.createProbot({
                id: process.env.APP_ID,
                secret: process.env.WEBHOOK_SECRET,
                cert: private_key_1.findPrivateKey(),
            });
    if (typeof appFn === 'string') {
        appFn = resolver_1.resolve(appFn);
    }
    probot.load(appFn);
    return probot;
};
exports.serverless = (appFn, appName, appVersion) => {
    return async (req, res) => {
        if (req.method === 'GET' && req.url === '/probot') {
            res.statusCode = 200;
            res.setHeader('Content-Type', 'text/html');
            res.end(probot_2.template(appName, appVersion));
            return;
        }
        probot = probot || loadProbot(appFn);
        const event = req.headers['x-github-event'] || req.headers['X-GitHub-Event'];
        try {
            const body = await micro_1.json(req);
            console.log(`Received event ${event}${body.action ? '.' + body.action : ''}`);
            res.setHeader('Content-Type', 'application/json; charset=utf-8');
            if (body.action) {
                try {
                    await probot.receive({
                        name: event,
                        payload: body,
                    });
                    res.statusCode = 200;
                    res.end(JSON.stringify({
                        message: `Received ${event}.${body.action}`,
                    }));
                    return;
                }
                catch (err) {
                    console.error(err);
                    res.statusCode = 500;
                    res.end(JSON.stringify(err));
                    return;
                }
            }
            else {
                console.error({ req });
                res.statusCode = 200;
                res.end(JSON.stringify({ message: 'Nothing to do' }));
                return;
            }
        }
        catch (err) {
            console.error('Could not deserialize body into JSON');
            res.end(JSON.stringify(err));
            return;
        }
    };
};
//# sourceMappingURL=index.js.map