"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const micro_1 = require("micro");
const __1 = require("../");
jest.mock('micro', () => {
    return Object.assign({}, require.requireActual('micro'), { json: jest.fn(async () => {
            return {
                action: 'issue',
            };
        }) });
});
describe('serverless-now', () => {
    let spy, handler, res;
    beforeEach(() => {
        micro_1.json.prototype.get = jest.fn(() => Promise.resolve({ action: 'issue' }));
        res = {
            end: jest.fn(),
            setHeader: jest.fn(),
        };
        spy = jest.fn();
        handler = __1.serverless(async (app) => {
            app.auth = () => Promise.resolve({});
            app.on('issues', spy);
        }, 'app', '1.0');
    });
    it('responds with the homepage', async () => {
        const req = { method: 'GET', url: '/probot' };
        await handler(req, res);
        expect(res.end).toHaveBeenCalled();
        expect(res.end.mock.calls[0][0]).toMatchSnapshot();
    });
    it('calls the event handler', async () => {
        const req = {
            body: {
                installation: { id: 1 },
            },
            headers: {
                'x-github-event': 'issues',
                'x-github-delivery': 123,
            },
        };
        await handler(req, res);
        expect(micro_1.json).toHaveBeenCalled();
        expect(res.end).toHaveBeenCalled();
        expect(spy).toHaveBeenCalled();
    });
});
//# sourceMappingURL=index.test.js.map